import React from 'react';
import PropTypes from 'prop-types';
import { createStyledComponent } from '@cloudflare/style-container';
var fontSizes = {
  normal: 3,
  small: 2
};
var lineHeights = {
  small: 1.25
};
var colors = {
  info: 'blue.4',
  success: 'green.5',
  warning: 'orange.6',
  error: 'red.3',
  muted: 'gray.4'
};
var fontWeights = {
  normal: 400,
  bold: 700,
  'semi-bold': 600
};
var textAlign = {
  start: 'left',
  center: 'center',
  justify: 'justify',
  end: 'right'
};

var styles = _ref => {
  var {
    size,
    weight,
    align,
    type,
    case: textCase
  } = _ref;
  return {
    color: type && colors[type],
    lineHeight: size && lineHeights[size],
    fontSize: size && fontSizes[size],
    fontWeight: weight && fontWeights[weight],
    textAlign: align && textAlign[align],
    textTransform: textCase,
    '&:first-letter': {
      textTransform: textCase && textCase === 'titlecase' && 'capitalize'
    }
  };
};

class Text extends React.Component {
  render() {
    var {
      className,
      role,
      children
    } = this.props;
    return /*#__PURE__*/React.createElement("div", {
      className: className,
      role: role
    }, children);
  }

}

Text.propTypes = {
  size: PropTypes.oneOf(['normal', 'small']),
  weight: PropTypes.oneOf(['normal', 'semi-bold', 'bold']),
  align: PropTypes.oneOf(['start', 'center', 'justify', 'end']),
  type: PropTypes.oneOf(['info', 'success', 'warning', 'error', 'muted']),
  case: PropTypes.oneOf(['capitalize', 'titlecase', 'lowercase', 'uppercase']),
  role: PropTypes.string,
  className: PropTypes.string.isRequired,
  children: PropTypes.node
};
Text.defaultProps = {
  weight: 'normal'
};
Text.displayName = 'Text';
export default createStyledComponent(styles, Text, ['role']);